// -----------------------------------------------------------------------------
//
// Author(s):     Peter Schraut (www.console-dev.de)
// Last Modified: 18th April 2006
//
// Purpose:       Demo shows how to use the window-system.
//
// -----------------------------------------------------------------------------
#include <hel2.h>
#include "ResourceData.h"

// -----------------------------------------------------------------------------
// Global Variables
// -----------------------------------------------------------------------------
volatile u32 ATTR_EWRAM g_FramesTotal=0;

// -----------------------------------------------------------------------------
// Prototypes
// -----------------------------------------------------------------------------
void VBLInterruptHandler(void);



// -----------------------------------------------------------------------------
// Program Entry Point
// -----------------------------------------------------------------------------
int main(void)
{
    ham_Init();
    hel_SysSetPrefetch(TRUE);
    ham_SetBgMode(4);

    // initialize window-system
    hel_WinInit();
    
    // Load Backgroundpicture and immediatly
    // flip the backbuffer to display its content.
    hel_BmpLoad(ResData(RES_GIRLBG_RAW));
    ham_FlipBGBuffer();

    // Init a Window
    hel_WinCreate(0,          // WinNo
                  30,         // Left
                  30,         // Top
                  60,         // Right
                  60,         // Bottom
                  WIN_ALL,    // InsideFlags
                  WIN_NONE);  // OutsideFlags

    // Load Background Palette
    hel_PalBgLoad256(ResData(RES_GIRLBG_PAL));
    
    // Start VBL Interrupt
    hel_IntrStartHandler(INT_TYPE_VBL, (void*)VBLInterruptHandler);
    
    
    for(;;)
    {
        #define WINDOW_WIDTH  75
        #define WINDOW_HEIGHT 75

        if(!(g_FramesTotal&15))
        {
           int x = rand()%(SCREEN_DISPLAY_WIDTH - WINDOW_WIDTH);
           int y = rand()%(SCREEN_DISPLAY_HEIGHT - WINDOW_HEIGHT);
           
           hel_WinSetRegion(0, x, y, x+WINDOW_WIDTH, y+WINDOW_HEIGHT);
        }
        
        // Wait for Vertical Blank
        hel_SwiVBlankIntrWait();
    }
}


// -----------------------------------------------------------------------------
// VBL Interrupt Handler
// -----------------------------------------------------------------------------
void VBLInterruptHandler()
{
   // Transmit HEL's shadowed Window Attributes
   // to Hardware to see changes.
   hel_WinTransmit();

   g_FramesTotal++;
   
   hel_IntrAcknowledge(INT_TYPE_VBL);
}

